.. _authors:

Authors
=======

To see who contributed to ``pyirf``, please visit the
`GitHub contributors page <https://github.com/cta-observatory/pyirf/graphs/contributors>`__
or run

.. code-block:: bash

    git shortlog -sne


``pyirf`` started as part of `protopipe <https://github.com/cta-observatory/protopipe/>`__ by Julien Lefaucher,
but was largely rewritten in September 2020, making use of code from the
previous version, the `pyfact <http://github.com/fact-project/pyfact>`__ module and the
`FACT irf <http://github.com/fact-project/irf>`__ package.
